            
/*
If you wonder why we have queries with 'WHERE NOT EXISTS', we only insert the row if it already does not exist. Just google the term 'idempotent' operations.

Was wird hier alles konfiguriert?

Zahlarten : Vorkasse(2), CREDITCARD( 3), ON_DELIVERY( 4), ON_ACCOUNT( 5), Sofortueberweisung( 9), PayPal(10), GIROPAY( 21), BPS_INVOICE_TOTAL_ZERO( 100)

	- ProcessControlConfig fuer Invoicing
		- ojectType Order, processesRef CheckOrder, shopRef Ocelot
		- ojectType Return, processesRef CloseReturn, shopRef Ocelot
	- ProcessControlLineConfig	fuer Invoicing
		- CheckOrderQueue
			- targetProcesses AnnounceOrderQueue, ojectType Order, processType STATUS
			- targetProcesses EventControlQueue, ojectType Order, processType EVENT
		- CloseReturnQueue
			- targetProcesses EventControlQueue, ojectType Return, processType EVENT
			- targetProcesses ReturnTransmissionRequiredQueue, ojectType Return, processType STATUS				
	- EventRegistryEntry fuer Invoicing
		- CheckOrder
		- CloseReturn
	- InvoicingEventRegistryEntryDO
		- Rechnung for alle Zahlarten on CheckOrderQueue
		- Gutschrift for alle Zahlarten on CloseReturnQueue
	-- Nummerngenerierung
		-- InvoicingNoConfigDO    
			-- Nummerngenerierung mit LONG_NO_SEQUENCER ein Nummernkreis fuer Rechnung und Gutschrift
			-- //Nummerngenerierung mit LONG_NO_SEQUENCER fuer Rechnung
			-- //Nummerngenerierung mit LONG_NO_SEQUENCER fuer Gutschrift  
		-- DebitorNumberRangeConfigDO - wenn keine Konfig vorhanden, wird fuer DebitorNo die ShopCustomerNo verwendet
			-- //Nummerngenerierung mit LONG_SEQUENCER fuer Debitor			  
	- Erzeugung Dokumente 
		- // CommunicationDO fuer CREATE_DOCUMENT_SYNCH
	-- CommunicationPartnerDO
		-- Erstellung Dokument	
	-- ExcecutionBeanValueDO
	-- Erstellung Dokument
	-- DocumentTransformerConfigDO fuer documentTypeDefRef=invoiceCreditNote (17)
	
 */
 
 
DO $$
DECLARE

  shop_inTRONICS           int8 = (select id from oms."ShopDO" where "internalShopName"='inTRONICS');
  shop_inTRONICS_Business           int8 = (select id from oms."ShopDO" where "internalShopName"='inTRONICS_Business');
  
BEGIN
 
       
	-- ############################################################################################
	-- # PCM Konfiguration zur Erzeugung von Invoicings #
	-- ############################################################################################		
-- ProcessControlConfig fuer Invoicing
-- ojectType Order, processesRef CheckOrderQueue (Async TRUE Sync TRUE)
INSERT INTO "ProcessControlConfigDO" ("id","objectTypeDefRef","version","processesRef","shopRef","supplierRef","creationDate","modificationDate")
	SELECT nextval('"ProcessControlConfigDO_id_seq"'),10,0,1,shop_inTRONICS,null::int8,CURRENT_TIMESTAMP,CURRENT_TIMESTAMP
	WHERE NOT EXISTS
		(
		SELECT 1 from "ProcessControlConfigDO" where "objectTypeDefRef" = 10 and "processesRef" = 1 and "shopRef" = shop_inTRONICS and "supplierRef" isNull
		)
UNION ALL		
-- ojectType Order, processesRef CheckOrderQueue (Async TRUE Sync TRUE)
	SELECT nextval('"ProcessControlConfigDO_id_seq"'),10,0,1,shop_inTRONICS_Business,null,CURRENT_TIMESTAMP,CURRENT_TIMESTAMP
	WHERE NOT EXISTS
		(
		SELECT 1 from "ProcessControlConfigDO" where "objectTypeDefRef" = 10 and "processesRef" = 1 and "shopRef" = shop_inTRONICS_Business and "supplierRef" isNull
		)
UNION ALL
-- ojectType Return, processesRef "CloseReturnQueue" (Async TRUE Sync FALSE)
	SELECT nextval('"ProcessControlConfigDO_id_seq"'),40,0,15,shop_inTRONICS,null,CURRENT_TIMESTAMP,CURRENT_TIMESTAMP
	WHERE NOT EXISTS
		(
		SELECT 1 from "ProcessControlConfigDO" where "objectTypeDefRef" = 40 and "processesRef" = 15 and "shopRef" = shop_inTRONICS and "supplierRef" isNull
		)
UNION ALL
-- ojectType Return, processesRef "CloseReturnQueue" (Async TRUE Sync FALSE)
	SELECT nextval('"ProcessControlConfigDO_id_seq"'),40,0,15,shop_inTRONICS_Business,null,CURRENT_TIMESTAMP,CURRENT_TIMESTAMP
	WHERE NOT EXISTS
		(
		SELECT 1 from "ProcessControlConfigDO" where "objectTypeDefRef" = 40 and "processesRef" = 15 and "shopRef" = shop_inTRONICS_Business and "supplierRef" isNull
		);
-- ProcessControlLineConfig	fuer Invoicing
-- CheckOrderQueue -> processControlConfigRef
-- soruce = targetProcesses -> AnnounceOrderQueue, objectType Order, processType STATUS
-- shop_inTRONICS
INSERT INTO "ProcessControlLineConfigDO" ("id","version","processControlConfigRef","sourceProcessesRef","targetProcessesRef","sourceState","targetState","objectTypeDefRef","processTypeDefRef","creationDate","modificationDate") 
	-- source process = target process = 2 -> AnnounceOrderQueue 
	-- objectTypeDefRef = 10 (Order) & processTypeDefRef = 1 (Status)
    SELECT nextval('"ProcessControlLineConfigDO_id_seq"'),0,(select id from "ProcessControlConfigDO" where "objectTypeDefRef" = 10 and "processesRef" = 1 and "shopRef" = shop_inTRONICS and "supplierRef" isNull ),2,2,null,null,10, 1,CURRENT_TIMESTAMP,CURRENT_TIMESTAMP
    WHERE NOT EXISTS
    	(
    	SELECT 1 from "ProcessControlLineConfigDO" where "processControlConfigRef" = (select id from "ProcessControlConfigDO" where "objectTypeDefRef" = 10 and "processesRef" = 1 and "shopRef" = shop_inTRONICS and "supplierRef" isNull) and "sourceProcessesRef" = 2 and "targetProcessesRef" = 2 and "sourceState" isNull and "targetState" isNull and "objectTypeDefRef" = 10 and "processTypeDefRef" = 1
    	);
-- shop_inTRONICS_Business
INSERT INTO "ProcessControlLineConfigDO" ("id","version","processControlConfigRef","sourceProcessesRef","targetProcessesRef","sourceState","targetState","objectTypeDefRef","processTypeDefRef","creationDate","modificationDate")
	-- source process = target process = 2 -> AnnounceOrderQueue 
	-- objectTypeDefRef = 10 (Order) & processTypeDefRef = 1 (Status)
    SELECT nextval('"ProcessControlLineConfigDO_id_seq"'),0,(select id from "ProcessControlConfigDO" where "objectTypeDefRef" = 10 and "processesRef" = 1 and "shopRef" = shop_inTRONICS_Business and "supplierRef" isNull ),2,2,null,null,10, 1,CURRENT_TIMESTAMP,CURRENT_TIMESTAMP
    WHERE NOT EXISTS
    	(
    	SELECT 1 from "ProcessControlLineConfigDO" where "processControlConfigRef" = (select id from "ProcessControlConfigDO" where "objectTypeDefRef" = 10 and "processesRef" = 1 and "shopRef" = shop_inTRONICS_Business and "supplierRef" isNull) and "sourceProcessesRef" = 2 and "targetProcessesRef" = 2 and "sourceState" isNull and "targetState" isNull and "objectTypeDefRef" = 10 and "processTypeDefRef" = 1
    	);
		
-- CheckOrderQueue
-- targetProcess EventControlQueue, ojectType Order, processType EVENT
--shop_inTRONICS_Business
INSERT INTO "ProcessControlLineConfigDO" ("id","version","processControlConfigRef","sourceProcessesRef","targetProcessesRef","sourceState","targetState","objectTypeDefRef","processTypeDefRef","creationDate","modificationDate")
    SELECT nextval('"ProcessControlLineConfigDO_id_seq"'),0,(select id from "ProcessControlConfigDO" where "objectTypeDefRef" = 10 and "processesRef" = 1 and "shopRef" = shop_inTRONICS_Business and "supplierRef" isNull ),null,81,null,null,10, 3,CURRENT_TIMESTAMP,CURRENT_TIMESTAMP
    WHERE NOT EXISTS
    	(
    	SELECT 1 from "ProcessControlLineConfigDO" where "processControlConfigRef" = (select id from "ProcessControlConfigDO" where "objectTypeDefRef" = 10 and "processesRef" = 1 and "shopRef" = shop_inTRONICS_Business and "supplierRef" isNull) and "sourceProcessesRef" isNull and "targetProcessesRef" = 81 and "sourceState" isNull and "targetState" isNull and "objectTypeDefRef" = 10 and "processTypeDefRef" = 3
    	);
--shop_inTRONICS
INSERT INTO "ProcessControlLineConfigDO" ("id","version","processControlConfigRef","sourceProcessesRef","targetProcessesRef","sourceState","targetState","objectTypeDefRef","processTypeDefRef","creationDate","modificationDate")
    SELECT nextval('"ProcessControlLineConfigDO_id_seq"'),0,(select id from "ProcessControlConfigDO" where "objectTypeDefRef" = 10 and "processesRef" = 1 and "shopRef" = shop_inTRONICS and "supplierRef" isNull ),null,81,null,null,10, 3,CURRENT_TIMESTAMP,CURRENT_TIMESTAMP
    WHERE NOT EXISTS
    	(
    	SELECT 1 from "ProcessControlLineConfigDO" where "processControlConfigRef" = (select id from "ProcessControlConfigDO" where "objectTypeDefRef" = 10 and "processesRef" = 1 and "shopRef" = shop_inTRONICS and "supplierRef" isNull) and "sourceProcessesRef" isNull and "targetProcessesRef" = 81 and "sourceState" isNull and "targetState" isNull and "objectTypeDefRef" = 10 and "processTypeDefRef" = 3
    	);	
		
-- CloseReturnQueue
-- targetProcesses EventControlQueue, ojectType Return, processType EVENT
--shop_inTRONICS
INSERT INTO "ProcessControlLineConfigDO" ("id","version","processControlConfigRef","sourceProcessesRef","targetProcessesRef","sourceState","targetState","objectTypeDefRef","processTypeDefRef","creationDate","modificationDate")
    SELECT nextval('"ProcessControlLineConfigDO_id_seq"'),0,(select id from "ProcessControlConfigDO" where "objectTypeDefRef" = 40 and "processesRef" = 15 and "shopRef" = shop_inTRONICS and "supplierRef" isNull ),null,81,null,null,40, 3,CURRENT_TIMESTAMP,CURRENT_TIMESTAMP
    WHERE NOT EXISTS
    	(
    	SELECT 1 from "ProcessControlLineConfigDO" where "processControlConfigRef" = (select id from "ProcessControlConfigDO" where "objectTypeDefRef" = 40 and "processesRef" = 15 and "shopRef" = shop_inTRONICS and "supplierRef" isNull) and "sourceProcessesRef" isNull and "targetProcessesRef" = 81 and "sourceState" isNull and "targetState" isNull and "objectTypeDefRef" = 40 and "processTypeDefRef" = 3
    	);
--shop_inTRONICS_Business
INSERT INTO "ProcessControlLineConfigDO" ("id","version","processControlConfigRef","sourceProcessesRef","targetProcessesRef","sourceState","targetState","objectTypeDefRef","processTypeDefRef","creationDate","modificationDate")
    SELECT nextval('"ProcessControlLineConfigDO_id_seq"'),0,(select id from "ProcessControlConfigDO" where "objectTypeDefRef" = 40 and "processesRef" = 15 and "shopRef" = shop_inTRONICS_Business and "supplierRef" isNull ),null,81,null,null,40, 3,CURRENT_TIMESTAMP,CURRENT_TIMESTAMP
    WHERE NOT EXISTS
    	(
    	SELECT 1 from "ProcessControlLineConfigDO" where "processControlConfigRef" = (select id from "ProcessControlConfigDO" where "objectTypeDefRef" = 40 and "processesRef" = 15 and "shopRef" = shop_inTRONICS_Business and "supplierRef" isNull) and "sourceProcessesRef" isNull and "targetProcessesRef" = 81 and "sourceState" isNull and "targetState" isNull and "objectTypeDefRef" = 40 and "processTypeDefRef" = 3
    	);
-- CloseReturnQueue
-- targetProcesses ReturnTransmissionRequiredQueue, ojectType Return, processType STATUS
--shop_inTRONICS_Business
INSERT INTO "ProcessControlLineConfigDO" ("id","version","processControlConfigRef","sourceProcessesRef","targetProcessesRef","sourceState","targetState","objectTypeDefRef","processTypeDefRef","creationDate","modificationDate")
    SELECT nextval('"ProcessControlLineConfigDO_id_seq"'),0,(select id from "ProcessControlConfigDO" where "objectTypeDefRef" = 40 and "processesRef" = 15 and "shopRef" = shop_inTRONICS_Business and "supplierRef" isNull ),16,16,null,null,40, 1,CURRENT_TIMESTAMP,CURRENT_TIMESTAMP
    WHERE NOT EXISTS
    	(
    	SELECT 1 from "ProcessControlLineConfigDO" where "processControlConfigRef" = (select id from "ProcessControlConfigDO" where "objectTypeDefRef" = 40 and "processesRef" = 15 and "shopRef" = shop_inTRONICS_Business and "supplierRef" isNull) and "sourceProcessesRef" = 16 and "targetProcessesRef" = 16 and "sourceState" isNull and "targetState" isNull and "objectTypeDefRef" = 40 and "processTypeDefRef" = 1
    	);
--shop_inTRONICS
INSERT INTO "ProcessControlLineConfigDO" ("id","version","processControlConfigRef","sourceProcessesRef","targetProcessesRef","sourceState","targetState","objectTypeDefRef","processTypeDefRef","creationDate","modificationDate")
    SELECT nextval('"ProcessControlLineConfigDO_id_seq"'),0,(select id from "ProcessControlConfigDO" where "objectTypeDefRef" = 40 and "processesRef" = 15 and "shopRef" = shop_inTRONICS and "supplierRef" isNull ),16,16,null,null,40, 1,CURRENT_TIMESTAMP,CURRENT_TIMESTAMP
    WHERE NOT EXISTS
    	(
    	SELECT 1 from "ProcessControlLineConfigDO" where "processControlConfigRef" = (select id from "ProcessControlConfigDO" where "objectTypeDefRef" = 40 and "processesRef" = 15 and "shopRef" = shop_inTRONICS and "supplierRef" isNull) and "sourceProcessesRef" = 16 and "targetProcessesRef" = 16 and "sourceState" isNull and "targetState" isNull and "objectTypeDefRef" = 40 and "processTypeDefRef" = 1
    	);
        
	-- ############################################################################################
	-- # Invoicing als Event-Prozess #
	-- ############################################################################################
-- EventRegistryEntry Invoicing
--shop_inTRONICS
INSERT INTO "EventRegistryEntryDO" ("id","creationDate","modificationDate","processesRef","version","eventDefRef","shopRef","description")
	SELECT nextval('"EventRegistryEntryDO_id_seq"'),CURRENT_TIMESTAMP,CURRENT_TIMESTAMP,1,1,3,shop_inTRONICS,'Events on CheckOrderQueue'
	WHERE NOT EXISTS
		(
		SELECT 1 from "EventRegistryEntryDO" where "processesRef"=1 and "eventDefRef"=3 and "shopRef"=shop_inTRONICS
		);
INSERT INTO "EventRegistryEntryDO" ("id","creationDate","modificationDate","processesRef","version","eventDefRef","shopRef","description")
	SELECT nextval('"EventRegistryEntryDO_id_seq"'),CURRENT_TIMESTAMP,CURRENT_TIMESTAMP,15,1,3,shop_inTRONICS,'Events on CloseReturnQueue'
	WHERE NOT EXISTS
		(
		SELECT 1 from "EventRegistryEntryDO" where "processesRef"=15 and "eventDefRef"=3 and "shopRef"=shop_inTRONICS
		);
--shop_inTRONICS_Business
INSERT INTO "EventRegistryEntryDO" ("id","creationDate","modificationDate","processesRef","version","eventDefRef","shopRef","description")
	SELECT nextval('"EventRegistryEntryDO_id_seq"'),CURRENT_TIMESTAMP,CURRENT_TIMESTAMP,1,1,3,shop_inTRONICS_Business,'Events on CheckOrderQueue'
	WHERE NOT EXISTS
		(
		SELECT 1 from "EventRegistryEntryDO" where "processesRef"=1 and "eventDefRef"=3 and "shopRef"=shop_inTRONICS_Business
		);
INSERT INTO "EventRegistryEntryDO" ("id","creationDate","modificationDate","processesRef","version","eventDefRef","shopRef","description")
	SELECT nextval('"EventRegistryEntryDO_id_seq"'),CURRENT_TIMESTAMP,CURRENT_TIMESTAMP,15,1,3,shop_inTRONICS_Business,'Events on CloseReturnQueue'
	WHERE NOT EXISTS
		(
		SELECT 1 from "EventRegistryEntryDO" where "processesRef"=15 and "eventDefRef"=3 and "shopRef"=shop_inTRONICS_Business
		);
		
-- InvoicingEventRegistryEntryDO
-- Rechnung for All on CheckOrderQueue
--shop_inTRONICS_Business
INSERT INTO "InvoicingEventRegistryEntryDO" ("id","creationDate","modificationDate","eventRegistryEntryRef","version","active","paymentDefRef","invoicingTypeDefRef","invoicingEventDefRef","decisionBeanDefRef")
    SELECT nextval('"InvoicingEventRegistryEntryDO_id_seq"'),CURRENT_TIMESTAMP,CURRENT_TIMESTAMP,(select id from "EventRegistryEntryDO" where "processesRef"=1 and "eventDefRef"=3 and "shopRef"=shop_inTRONICS_Business),0,true,null,1,1,120
    WHERE NOT EXISTS
		(
		SELECT 1 from "InvoicingEventRegistryEntryDO" where "eventRegistryEntryRef" = (select id from "EventRegistryEntryDO" where "processesRef"=1 and "eventDefRef"=3 and "shopRef"=shop_inTRONICS_Business) and "invoicingEventDefRef" = 1 and "paymentDefRef" = 2 and "invoicingTypeDefRef" = 1 and "decisionBeanDefRef" = 120
		);

--shop_inTRONICS
INSERT INTO "InvoicingEventRegistryEntryDO" ("id","creationDate","modificationDate","eventRegistryEntryRef","version","active","paymentDefRef","invoicingTypeDefRef","invoicingEventDefRef","decisionBeanDefRef")
    SELECT nextval('"InvoicingEventRegistryEntryDO_id_seq"'),CURRENT_TIMESTAMP,CURRENT_TIMESTAMP,(select id from "EventRegistryEntryDO" where "processesRef"=1 and "eventDefRef"=3 and "shopRef"=shop_inTRONICS),0,true,null,1,1,120
    WHERE NOT EXISTS
		(
		SELECT 1 from "InvoicingEventRegistryEntryDO" where "eventRegistryEntryRef" = (select id from "EventRegistryEntryDO" where "processesRef"=1 and "eventDefRef"=3 and "shopRef"=shop_inTRONICS) and "invoicingEventDefRef" = 1 and "paymentDefRef" = 2 and "invoicingTypeDefRef" = 1 and "decisionBeanDefRef" = 120
		);
-- Gutschrift for ALL on CloseReturnQueue
--shop_inTRONICS_Business
INSERT INTO "InvoicingEventRegistryEntryDO" ("id","creationDate","modificationDate","eventRegistryEntryRef","version","active","paymentDefRef","invoicingTypeDefRef","invoicingEventDefRef","decisionBeanDefRef")
    SELECT nextval('"InvoicingEventRegistryEntryDO_id_seq"'),CURRENT_TIMESTAMP,CURRENT_TIMESTAMP,(select id from "EventRegistryEntryDO" where "processesRef"=15 and "eventDefRef"=3 and "shopRef"=shop_inTRONICS_Business),0,true,null,2,1,120
    WHERE NOT EXISTS
		(
		SELECT 1 from "InvoicingEventRegistryEntryDO" where "eventRegistryEntryRef" = (select id from "EventRegistryEntryDO" where "processesRef"=15 and "eventDefRef"=3 and "shopRef"=shop_inTRONICS_Business) and "invoicingEventDefRef" = 1 and "paymentDefRef" isNull and "invoicingTypeDefRef" = 2 and "decisionBeanDefRef" = 120
		);
--shop_inTRONICS
INSERT INTO "InvoicingEventRegistryEntryDO" ("id","creationDate","modificationDate","eventRegistryEntryRef","version","active","paymentDefRef","invoicingTypeDefRef","invoicingEventDefRef","decisionBeanDefRef")
    SELECT nextval('"InvoicingEventRegistryEntryDO_id_seq"'),CURRENT_TIMESTAMP,CURRENT_TIMESTAMP,(select id from "EventRegistryEntryDO" where "processesRef"=15 and "eventDefRef"=3 and "shopRef"=shop_inTRONICS),0,true,null,2,1,120
    WHERE NOT EXISTS
		(
		SELECT 1 from "InvoicingEventRegistryEntryDO" where "eventRegistryEntryRef" = (select id from "EventRegistryEntryDO" where "processesRef"=15 and "eventDefRef"=3 and "shopRef"=shop_inTRONICS) and "invoicingEventDefRef" = 1 and "paymentDefRef" isNull and "invoicingTypeDefRef" = 2 and "decisionBeanDefRef" = 120
		);
	
 	
	-- ############################################################################################
	-- # Nummernkreise fuer Invoicing und Debitor #
	-- ############################################################################################ 
-- InvoicingNoConfigDO 
-- Nummerngenerierung mit LONG_NO_SEQUENCER fuer Rechnungen und Gutschriften innerhalb des gleichen Nummernkreises
--shop_inTRONICS
INSERT INTO "InvoicingNoConfigDO"(id, "name", "countGenerated", "creationDate", enabled, "generationDate","startNumber","endNumber", "numberRangeFormatterDefRef", "invoicingTypeDefRef","lastGeneratedNumber", "maxNotAllocatedInvoiceNo", "modificationDate", "startDate","shopRef", version)
    VALUES (nextval('"InvoicingNoConfigDO_id_seq"'), 'Rechnungsnummer und Gutschriftsnummer', 0, CURRENT_TIMESTAMP, true, null, '2014000000', '2014999999', 5, null, null, 5, CURRENT_TIMESTAMP,CURRENT_TIMESTAMP,shop_inTRONICS, 1);
--shop_inTRONICS_Business
INSERT INTO "InvoicingNoConfigDO"(id, "name", "countGenerated", "creationDate", enabled, "generationDate","startNumber","endNumber", "numberRangeFormatterDefRef", "invoicingTypeDefRef","lastGeneratedNumber", "maxNotAllocatedInvoiceNo", "modificationDate", "startDate","shopRef", version)
    VALUES (nextval('"InvoicingNoConfigDO_id_seq"'), 'Rechnungsnummer und Gutschriftsnummer', 0, CURRENT_TIMESTAMP, true, null, '2016000000', '2016999999', 5, null, null, 5, CURRENT_TIMESTAMP,CURRENT_TIMESTAMP,shop_inTRONICS_Business, 1);

		
	-- ############################################################################################
	-- # Rechnungsdokumentenerstellung #
	-- ############################################################################################			

-- CommunicationPartnerDO	
-- Erstellung Dokument fuer sendingPartner und receivingPartner (excecutionBeanDefRef = 65 -> documentExcecutionSyncDeciderBean = 25) (transmissionTypeDefRef = 300 -> createDocument -> roleDef = 2) (documentFormatDefRef = 1 -> PDF-Format und Encoding fuer PDF)
--shop_inTRONICS_Business
INSERT INTO "CommunicationPartnerDO" ("id", "decisionBeanDefRef", "splitTransmission", "communicationRef", "receivingPartnerReferrerRef", "sendingPartnerReferrerRef", "maxNoOfRetries", "retryDelay", "mergeTypeDefRef")
    SELECT nextval('"CommunicationPartnerDO_id_seq"'), 25, false, ( select "id" from "CommunicationDO" where "executionBeanDefRef"=65 and "transmissionTypeDefRef"=300 and "documentFormatDefRef"=1 ), (select "id" from "PartnerReferrerDO" where "shopRef" = shop_inTRONICS_Business), (select "id" from "PartnerReferrerDO" where "shopRef" = shop_inTRONICS_Business), 5, '2m', null
    WHERE NOT EXISTS
		(
		SELECT 1 from "CommunicationPartnerDO" where "communicationRef" in ( select "id" from "CommunicationDO" where "executionBeanDefRef"=65 and "transmissionTypeDefRef"=300 and "documentFormatDefRef"=1 ) and "receivingPartnerReferrerRef"=(select "id" from "PartnerReferrerDO" where "shopRef" = shop_inTRONICS_Business) and "sendingPartnerReferrerRef"=(select "id" from "PartnerReferrerDO" where "shopRef" = shop_inTRONICS_Business)
		);

--shop_inTRONICS
INSERT INTO "CommunicationPartnerDO" ("id", "decisionBeanDefRef", "splitTransmission", "communicationRef", "receivingPartnerReferrerRef", "sendingPartnerReferrerRef", "maxNoOfRetries", "retryDelay", "mergeTypeDefRef")
    SELECT nextval('"CommunicationPartnerDO_id_seq"'), 25, false, ( select "id" from "CommunicationDO" where "executionBeanDefRef"=65 and "transmissionTypeDefRef"=300 and "documentFormatDefRef"=1 ), (select "id" from "PartnerReferrerDO" where "shopRef" = shop_inTRONICS), (select "id" from "PartnerReferrerDO" where "shopRef" = shop_inTRONICS), 5, '2m', null
    WHERE NOT EXISTS
		(
		SELECT 1 from "CommunicationPartnerDO" where "communicationRef" in ( select "id" from "CommunicationDO" where "executionBeanDefRef"=65 and "transmissionTypeDefRef"=300 and "documentFormatDefRef"=1 ) and "receivingPartnerReferrerRef"=(select "id" from "PartnerReferrerDO" where "shopRef" = shop_inTRONICS) and "sendingPartnerReferrerRef"=(select "id" from "PartnerReferrerDO" where "shopRef" = shop_inTRONICS)
		);
		
-- ExcecutionBeanValueDO 

--shop_inTRONICS_Business -> shop_inTRONICS_Business
-- Erstellung Dokument - documentFormat
INSERT INTO "ExecutionBeanValueDO"("id", "executionBeanKeyDefRef", "parameterValue", "communicationPartnerRef")
    SELECT nextval('"ExecutionBeanValueDO_id_seq"'),213,'PDF', (select "id" from "CommunicationPartnerDO" where ("communicationRef" in (select "id" from "CommunicationDO" where "executionBeanDefRef"=65 and "transmissionTypeDefRef"=300 and "documentFormatDefRef"=1 ) and "receivingPartnerReferrerRef"=(select "id" from "PartnerReferrerDO" where "shopRef" = shop_inTRONICS_Business) and "sendingPartnerReferrerRef"=((select "id" from "PartnerReferrerDO" where "shopRef" = shop_inTRONICS_Business))))
    WHERE NOT EXISTS
		(
		SELECT 1 from "ExecutionBeanValueDO" 
		where "executionBeanKeyDefRef"=213 
		and "parameterValue" ='PDF'
		and "communicationPartnerRef"= (select "id" from "CommunicationPartnerDO" where ("communicationRef" in ( select "id" from "CommunicationDO" where "executionBeanDefRef"=65 and "transmissionTypeDefRef"=300 and "documentFormatDefRef"=1 ) and "receivingPartnerReferrerRef"=(select "id" from "PartnerReferrerDO" where "shopRef" = shop_inTRONICS_Business) and "sendingPartnerReferrerRef"=(select "id" from "PartnerReferrerDO" where "shopRef" = shop_inTRONICS_Business)))
		);
-- Erstellung Dokument - documentType		
INSERT INTO "ExecutionBeanValueDO"("id", "executionBeanKeyDefRef", "parameterValue", "communicationPartnerRef")
    SELECT nextval('"ExecutionBeanValueDO_id_seq"'),214,'INVOICE_CREDIT_NOTE', (select "id" from "CommunicationPartnerDO" where ("communicationRef" in (select "id" from "CommunicationDO" where "executionBeanDefRef"=65 and "transmissionTypeDefRef"=300 and "documentFormatDefRef"=1 ) and "receivingPartnerReferrerRef"=(	select "id" from "PartnerReferrerDO" where "shopRef" = shop_inTRONICS_Business) and "sendingPartnerReferrerRef"=((select "id" from "PartnerReferrerDO" where "shopRef" = shop_inTRONICS_Business))))
    WHERE NOT EXISTS
		(
		SELECT 1 from "ExecutionBeanValueDO" 
		where "executionBeanKeyDefRef"=214 
		and "parameterValue" ='INVOICE_CREDIT_NOTE'
		and "communicationPartnerRef"= (select "id" from "CommunicationPartnerDO" where ("communicationRef" in ( select "id" from "CommunicationDO" where "executionBeanDefRef"=65 and "transmissionTypeDefRef"=300 and "documentFormatDefRef"=1 ) and "receivingPartnerReferrerRef"=(select "id" from "PartnerReferrerDO" where "shopRef" = shop_inTRONICS_Business) and "sendingPartnerReferrerRef"=(select "id" from "PartnerReferrerDO" where "shopRef" = shop_inTRONICS_Business)))
		);
-- Erstellung Dokument - welches - addInvoiceCreditNote	
INSERT INTO "ExecutionBeanValueDO"("id", "executionBeanKeyDefRef", "parameterValue", "communicationPartnerRef")
    SELECT nextval('"ExecutionBeanValueDO_id_seq"'),215,true::varchar, (select "id" from "CommunicationPartnerDO" where ("communicationRef" in (select "id" from "CommunicationDO" where "executionBeanDefRef"=65 and "transmissionTypeDefRef"=300 and "documentFormatDefRef"=1 ) and "receivingPartnerReferrerRef"=(	select "id" from "PartnerReferrerDO" where "shopRef" = shop_inTRONICS_Business) and "sendingPartnerReferrerRef"=((select "id" from "PartnerReferrerDO" where "shopRef" = shop_inTRONICS_Business))))
    WHERE NOT EXISTS
		(
		SELECT 1 from "ExecutionBeanValueDO" 
		where "executionBeanKeyDefRef"=215 
		and "parameterValue" =true::varchar
		and "communicationPartnerRef"= (select "id" from "CommunicationPartnerDO" where ("communicationRef" in ( select "id" from "CommunicationDO" where "executionBeanDefRef"=65 and "transmissionTypeDefRef"=300 and "documentFormatDefRef"=1 ) and "receivingPartnerReferrerRef"=(select "id" from "PartnerReferrerDO" where "shopRef" = shop_inTRONICS_Business) and "sendingPartnerReferrerRef"=(select "id" from "PartnerReferrerDO" where "shopRef" = shop_inTRONICS_Business)))
		);
-- shop_inTRONICS -> shop_inTRONICS
-- Erstellung Dokument - documentFormat
INSERT INTO "ExecutionBeanValueDO"("id", "executionBeanKeyDefRef", "parameterValue", "communicationPartnerRef")
    SELECT nextval('"ExecutionBeanValueDO_id_seq"'),213,'PDF', (select "id" from "CommunicationPartnerDO" where ("communicationRef" in (select "id" from "CommunicationDO" where "executionBeanDefRef"=65 and "transmissionTypeDefRef"=300 and "documentFormatDefRef"=1 ) and "receivingPartnerReferrerRef"=(select "id" from "PartnerReferrerDO" where "shopRef" = shop_inTRONICS) and "sendingPartnerReferrerRef"=((select "id" from "PartnerReferrerDO" where "shopRef" = shop_inTRONICS))))
    WHERE NOT EXISTS
		(
		SELECT 1 from "ExecutionBeanValueDO" 
		where "executionBeanKeyDefRef"=213 
		and "parameterValue" ='PDF'
		and "communicationPartnerRef"= (select "id" from "CommunicationPartnerDO" where ("communicationRef" in ( select "id" from "CommunicationDO" where "executionBeanDefRef"=65 and "transmissionTypeDefRef"=300 and "documentFormatDefRef"=1 ) and "receivingPartnerReferrerRef"=(select "id" from "PartnerReferrerDO" where "shopRef" = shop_inTRONICS) and "sendingPartnerReferrerRef"=(select "id" from "PartnerReferrerDO" where "shopRef" = shop_inTRONICS)))
		);
-- Erstellung Dokument - documentType		
INSERT INTO "ExecutionBeanValueDO"("id", "executionBeanKeyDefRef", "parameterValue", "communicationPartnerRef")
    SELECT nextval('"ExecutionBeanValueDO_id_seq"'),214,'INVOICE_CREDIT_NOTE', (select "id" from "CommunicationPartnerDO" where ("communicationRef" in (select "id" from "CommunicationDO" where "executionBeanDefRef"=65 and "transmissionTypeDefRef"=300 and "documentFormatDefRef"=1 ) and "receivingPartnerReferrerRef"=(	select "id" from "PartnerReferrerDO" where "shopRef" = shop_inTRONICS) and "sendingPartnerReferrerRef"=((select "id" from "PartnerReferrerDO" where "shopRef" = shop_inTRONICS))))
    WHERE NOT EXISTS
		(
		SELECT 1 from "ExecutionBeanValueDO" 
		where "executionBeanKeyDefRef"=214 
		and "parameterValue" ='INVOICE_CREDIT_NOTE'
		and "communicationPartnerRef"= (select "id" from "CommunicationPartnerDO" where ("communicationRef" in ( select "id" from "CommunicationDO" where "executionBeanDefRef"=65 and "transmissionTypeDefRef"=300 and "documentFormatDefRef"=1 ) and "receivingPartnerReferrerRef"=(select "id" from "PartnerReferrerDO" where "shopRef" = shop_inTRONICS) and "sendingPartnerReferrerRef"=(select "id" from "PartnerReferrerDO" where "shopRef" = shop_inTRONICS)))
		);
-- Erstellung Dokument - welches - addInvoiceCreditNote	
INSERT INTO "ExecutionBeanValueDO"("id", "executionBeanKeyDefRef", "parameterValue", "communicationPartnerRef")
    SELECT nextval('"ExecutionBeanValueDO_id_seq"'),215,true::varchar, (select "id" from "CommunicationPartnerDO" where ("communicationRef" in (select "id" from "CommunicationDO" where "executionBeanDefRef"=65 and "transmissionTypeDefRef"=300 and "documentFormatDefRef"=1 ) and "receivingPartnerReferrerRef"=(	select "id" from "PartnerReferrerDO" where "shopRef" = shop_inTRONICS) and "sendingPartnerReferrerRef"=((select "id" from "PartnerReferrerDO" where "shopRef" = shop_inTRONICS))))
    WHERE NOT EXISTS
		(
		SELECT 1 from "ExecutionBeanValueDO" 
		where "executionBeanKeyDefRef"=215 
		and "parameterValue" =true::varchar
		and "communicationPartnerRef"= (select "id" from "CommunicationPartnerDO" where ("communicationRef" in ( select "id" from "CommunicationDO" where "executionBeanDefRef"=65 and "transmissionTypeDefRef"=300 and "documentFormatDefRef"=1 ) and "receivingPartnerReferrerRef"=(select "id" from "PartnerReferrerDO" where "shopRef" = shop_inTRONICS) and "sendingPartnerReferrerRef"=(select "id" from "PartnerReferrerDO" where "shopRef" = shop_inTRONICS)))
		);
		
-- 	DocumentTransformerConfigDO fuer documentTypeDefRef=invoiceCreditNote (17)
--shop_inTRONICS
INSERT INTO "DocumentTransformerConfigDO"("id", "documentFormatDefRef", "documentMapperDefRef", "documentTypeDefRef", "shopRef", "transformerFrameworkDefRef", "save")
    SELECT nextval('"DocumentTransformerConfigDO_id_seq"'), 1, 2, 17, shop_inTRONICS, 2, TRUE
    WHERE NOT EXISTS
		(
		SELECT 1 from "DocumentTransformerConfigDO" where "shopRef" = shop_inTRONICS and "documentFormatDefRef"=1 and "documentMapperDefRef"=2 and "documentTypeDefRef"=17
		);
--shop_inTRONICS_Business
INSERT INTO "DocumentTransformerConfigDO"("id", "documentFormatDefRef", "documentMapperDefRef", "documentTypeDefRef", "shopRef", "transformerFrameworkDefRef", "save")
    SELECT nextval('"DocumentTransformerConfigDO_id_seq"'), 1, 2, 17, shop_inTRONICS_Business, 2, TRUE
    WHERE NOT EXISTS
		(
		SELECT 1 from "DocumentTransformerConfigDO" where "shopRef" = shop_inTRONICS_Business and "documentFormatDefRef"=1 and "documentMapperDefRef"=2 and "documentTypeDefRef"=17
		);
-- 	DocumentTransformerConfigDO fuer documentTypeDefRef=invoiceNote (18)
--shop_inTRONICS
INSERT INTO "DocumentTransformerConfigDO"("id", "documentFormatDefRef", "documentMapperDefRef", "documentTypeDefRef", "shopRef", "transformerFrameworkDefRef", "save")
    SELECT nextval('"DocumentTransformerConfigDO_id_seq"'), 1, 2, 18, shop_inTRONICS, 2, TRUE
    WHERE NOT EXISTS
		(
		SELECT 1 from "DocumentTransformerConfigDO" where "shopRef" = shop_inTRONICS and "documentFormatDefRef"=1 and "documentMapperDefRef"=2 and "documentTypeDefRef"=18
		);

--shop_inTRONICS_Business
INSERT INTO "DocumentTransformerConfigDO"("id", "documentFormatDefRef", "documentMapperDefRef", "documentTypeDefRef", "shopRef", "transformerFrameworkDefRef", "save")
    SELECT nextval('"DocumentTransformerConfigDO_id_seq"'), 1, 2, 18, shop_inTRONICS_Business, 2, TRUE
    WHERE NOT EXISTS
		(
		SELECT 1 from "DocumentTransformerConfigDO" where "shopRef" = shop_inTRONICS_Business and "documentFormatDefRef"=1 and "documentMapperDefRef"=2 and "documentTypeDefRef"=18
		);
-- 	DocumentTransformerConfigDO fuer documentTypeDefRef=creditNote (19)		
--shop_inTRONICS
INSERT INTO "DocumentTransformerConfigDO"("id", "documentFormatDefRef", "documentMapperDefRef", "documentTypeDefRef", "shopRef", "transformerFrameworkDefRef", "save")
    SELECT nextval('"DocumentTransformerConfigDO_id_seq"'), 1, 2, 19, shop_inTRONICS, 2, TRUE
    WHERE NOT EXISTS
		(
		SELECT 1 from "DocumentTransformerConfigDO" where "shopRef" = shop_inTRONICS and "documentFormatDefRef"=1 and "documentMapperDefRef"=2 and "documentTypeDefRef"=19
		);
--shop_inTRONICS_Business
INSERT INTO "DocumentTransformerConfigDO"("id", "documentFormatDefRef", "documentMapperDefRef", "documentTypeDefRef", "shopRef", "transformerFrameworkDefRef", "save")
    SELECT nextval('"DocumentTransformerConfigDO_id_seq"'), 1, 2, 19, shop_inTRONICS_Business, 2, TRUE
    WHERE NOT EXISTS
		(
		SELECT 1 from "DocumentTransformerConfigDO" where "shopRef" = shop_inTRONICS_Business and "documentFormatDefRef"=1 and "documentMapperDefRef"=2 and "documentTypeDefRef"=19
		);
-- 	DocumentTransformerConfigDO fuer documentTypeDefRef=deliveryNote (6)	
--shop_inTRONICS	
INSERT INTO "DocumentTransformerConfigDO"("id", "documentFormatDefRef", "documentMapperDefRef", "documentTypeDefRef", "shopRef", "transformerFrameworkDefRef", "save")
    SELECT nextval('"DocumentTransformerConfigDO_id_seq"'), 1, 2, 6, shop_inTRONICS, 2, TRUE
    WHERE NOT EXISTS
		(
		SELECT 1 from "DocumentTransformerConfigDO" where "shopRef" = shop_inTRONICS and "documentFormatDefRef"=1 and "documentMapperDefRef"=2 and "documentTypeDefRef"=6
		);
--shop_inTRONICS_Business
INSERT INTO "DocumentTransformerConfigDO"("id", "documentFormatDefRef", "documentMapperDefRef", "documentTypeDefRef", "shopRef", "transformerFrameworkDefRef", "save")
    SELECT nextval('"DocumentTransformerConfigDO_id_seq"'), 1, 2, 6, shop_inTRONICS_Business, 2, TRUE
    WHERE NOT EXISTS
		(
		SELECT 1 from "DocumentTransformerConfigDO" where "shopRef" = shop_inTRONICS_Business and "documentFormatDefRef"=1 and "documentMapperDefRef"=2 and "documentTypeDefRef"=6
		);
-- 	DocumentTransformerConfigDO fuer documentTypeDefRef=returnSlip (7)
--shop_inTRONICS
INSERT INTO "DocumentTransformerConfigDO"("id", "documentFormatDefRef", "documentMapperDefRef", "documentTypeDefRef", "shopRef", "transformerFrameworkDefRef", "save")
    SELECT nextval('"DocumentTransformerConfigDO_id_seq"'), 1, 2, 7, shop_inTRONICS, 2, TRUE
    WHERE NOT EXISTS
		(
		SELECT 1 from "DocumentTransformerConfigDO" where "shopRef" = shop_inTRONICS and "documentFormatDefRef"=1 and "documentMapperDefRef"=2 and "documentTypeDefRef"=7
		);
--shop_inTRONICS_Business
INSERT INTO "DocumentTransformerConfigDO"("id", "documentFormatDefRef", "documentMapperDefRef", "documentTypeDefRef", "shopRef", "transformerFrameworkDefRef", "save")
    SELECT nextval('"DocumentTransformerConfigDO_id_seq"'), 1, 2, 7, shop_inTRONICS_Business, 2, TRUE
    WHERE NOT EXISTS
		(
		SELECT 1 from "DocumentTransformerConfigDO" where "shopRef" = shop_inTRONICS_Business and "documentFormatDefRef"=1 and "documentMapperDefRef"=2 and "documentTypeDefRef"=7
		);
-- 	DocumentTransformerConfigDO fuer documentTypeDefRef=returnLabel (1) and "documentMapperDefRef"=1
--shop_inTRONICS
INSERT INTO "DocumentTransformerConfigDO"("id", "documentFormatDefRef", "documentMapperDefRef", "documentTypeDefRef", "shopRef", "transformerFrameworkDefRef", "save")
    SELECT nextval('"DocumentTransformerConfigDO_id_seq"'), 1, 1, 1, shop_inTRONICS, 2, TRUE
    WHERE NOT EXISTS
		(
		SELECT 1 from "DocumentTransformerConfigDO" where "shopRef" = shop_inTRONICS and "documentFormatDefRef"=1 and "documentMapperDefRef"=1 and "documentTypeDefRef"=1
		);
--shop_inTRONICS_Business
INSERT INTO "DocumentTransformerConfigDO"("id", "documentFormatDefRef", "documentMapperDefRef", "documentTypeDefRef", "shopRef", "transformerFrameworkDefRef", "save")
    SELECT nextval('"DocumentTransformerConfigDO_id_seq"'), 1, 1, 1, shop_inTRONICS_Business, 2, TRUE
    WHERE NOT EXISTS
		(
		SELECT 1 from "DocumentTransformerConfigDO" where "shopRef" = shop_inTRONICS_Business and "documentFormatDefRef"=1 and "documentMapperDefRef"=1 and "documentTypeDefRef"=1
		);		
END;        
$$;
