﻿/*

Author: 	Mani
Date: 		26.02.2016

For creditor and debtor related managements, XML files will be exported to the external finance controller (accounting system). 

Debtor:
Usually, shop customer (B2C) who makes payments to the shop for purchase(s) made.

Creditor: 
Usually, the supplier, who has to send the products to the customer. A customer owes money to the supplier for the purchase(s) made.

External Accounting System: 
Accounting service, which synchronizes debits and credits of your shop.
It is an intermediate item between creditor (i.e., supplier) and debtor (i.e., customer). The debtor pays to the creditor via an External Accounting System for the purchase(s).

*/

DO $$
DECLARE
  shop_inTRONICS           int8 = (select id from oms."ShopDO" where "internalShopName"='inTRONICS');
  shop_inTRONICS_Business           int8 = (select id from oms."ShopDO" where "internalShopName"='inTRONICS_Business');
  supplier_inTRONICS_Florida_Warehouse       int8 = (select id from oms."SupplierDO" where "internalSupplierName"='inTRONICS_florida_warehouse');
  supplier_inTRONICS_Florida_Retailer       int8 = (select id from oms."SupplierDO" where "internalSupplierName"='inTRONICS_florida_retailer');
  supplier_inTRONICS_Texas_Warehouse int8 = (select id from oms."SupplierDO" where "internalSupplierName"='inTRONICS_texas_warehouse');
  supplier_inTRONICS_Texas_Retailer int8 = (select id from oms."SupplierDO" where "internalSupplierName"='inTRONICS_texas_retailer');
  supplier_inTRONICS_California_Warehouse    int8 = (select id from oms."SupplierDO" where "internalSupplierName"='inTRONICS_california_warehouse');
  supplier_inTRONICS_California_Retailer    int8 = (select id from oms."SupplierDO" where "internalSupplierName"='inTRONICS_california_retailer');

BEGIN

INSERT INTO oms."FinanceControllerDO"("id", "name") values
    (nextval('"FinanceControllerDO_id_seq"') , 'FinanceController');

-- in order to make the finance controller eligible for communicating with other communication partners	
INSERT INTO "PartnerReferrerDO" ("id", "financeControllerRef") values
    (nextval('"PartnerReferrerDO_id_seq"') , (SELECT "id" FROM "FinanceControllerDO" WHERE "name" = 'FinanceController'));

-- hopefully, the shops have these payments already configured
INSERT INTO "FinanceController2PaymentDefDO" (id, "financeControllerRef", "financeControllerPaymentExportName", "financeControllerPaymentImportName", "paymentDefRef")
VALUES(nextval('"FinanceController2PaymentDefDO_id_seq"'), (SELECT "id" FROM "FinanceControllerDO" WHERE "name" = 'FinanceController'), 'RG', '00', 5),
    (nextval('"FinanceController2PaymentDefDO_id_seq"'), (SELECT "id" FROM "FinanceControllerDO" WHERE "name" = 'FinanceController'), 'CC', '55', 3),
    (nextval('"FinanceController2PaymentDefDO_id_seq"'), (SELECT "id" FROM "FinanceControllerDO" WHERE "name" = 'FinanceController'), 'GP', '51', 21),
    (nextval('"FinanceController2PaymentDefDO_id_seq"'), (SELECT "id" FROM "FinanceControllerDO" WHERE "name" = 'FinanceController'), 'PP', '60', 10),
    (nextval('"FinanceController2PaymentDefDO_id_seq"'), (SELECT "id" FROM "FinanceControllerDO" WHERE "name" = 'FinanceController'), 'COD', '80', 4),
    (nextval('"FinanceController2PaymentDefDO_id_seq"'), (SELECT "id" FROM "FinanceControllerDO" WHERE "name" = 'FinanceController'), 'EDD', '65', 7),
    (nextval('"FinanceController2PaymentDefDO_id_seq"'), (SELECT "id" FROM "FinanceControllerDO" WHERE "name" = 'FinanceController'), 'SO', '50', 9),
    (nextval('"FinanceController2PaymentDefDO_id_seq"'), (SELECT "id" FROM "FinanceControllerDO" WHERE "name" = 'FinanceController'), 'ISH', '01', 24),
    (nextval('"FinanceController2PaymentDefDO_id_seq"'), (SELECT "id" FROM "FinanceControllerDO" WHERE "name" = 'FinanceController'), 'COP', '02', 23),
    (nextval('"FinanceController2PaymentDefDO_id_seq"'), (SELECT "id" FROM "FinanceControllerDO" WHERE "name" = 'FinanceController'), 'PRE', '03', 2);	
	

INSERT INTO "FinanceController2TaxTypeDefDO" (id, "financeControllerRef", "financeControllerTaxTypeExportName", "financeControllerTaxTypeImportName", "taxTypeDefRef")
VALUES(nextval('"FinanceController2TaxTypeDefDO_id_seq"'), (SELECT "id" FROM "FinanceControllerDO" WHERE "name" = 'FinanceController'), '101', '001', 5),
    (nextval('"FinanceController2TaxTypeDefDO_id_seq"'), (SELECT "id" FROM "FinanceControllerDO" WHERE "name" = 'FinanceController'), '002', '002', 3),
    (nextval('"FinanceController2TaxTypeDefDO_id_seq"'), (SELECT "id" FROM "FinanceControllerDO" WHERE "name" = 'FinanceController'), '000', '000', 1);
	
INSERT INTO "Shop2FinanceControllerDO"("id", "financeControllerRef", "shopRef", "financeControllerShopName", "description") values
    (nextval('"Shop2FinanceControllerDO_id_seq"') , --id
    (SELECT "id" FROM "FinanceControllerDO" WHERE "name" = 'FinanceController'), --financeControllerRef
    shop_inTRONICS, --shopRef
    'PrimeTech Specials', --financeControllerShopName
    'Creditor Management for Shop PrimeTech Specials'); --description and end of insertion query	
	
INSERT INTO "Shop2FinanceControllerDO"("id", "financeControllerRef", "shopRef", "financeControllerShopName", "description") values
    (nextval('"Shop2FinanceControllerDO_id_seq"') , --id
    (SELECT "id" FROM "FinanceControllerDO" WHERE "name" = 'FinanceController'), --financeControllerRef
    shop_inTRONICS_Business, --shopRef
    'PrimeTech Business', --financeControllerShopName
    'Creditor Management for Shop PrimeTech Business'); --description and end of insertion query	

-- creditor management	
-- everytime dispatches and returns are confirmed by the supplier(s), an XML (open payments) will be exported to external finance controller
-- for dispatches, the finance controller will be informed how much money the shop-customer owes
-- for returns, the finance controller will be informed how much money should be paid to the shop-customer
-- shop specific	
INSERT INTO "CommunicationPartnerDO"
("id", "decisionBeanDefRef", "splitTransmission", "communicationRef", "sendingPartnerReferrerRef", "receivingPartnerReferrerRef", "maxNoOfRetries", "retryDelay", "mergeTypeDefRef")
values(
        nextval('"CommunicationPartnerDO_id_seq"'), -- id
        null, -- decisionBeanDefRef
        FALSE, -- splitTransmission
        (select id from "CommunicationDO" where "key" = 'XML###MESSAGE_FILE_SENDER_BEAN###SEND_OPEN_AMOUNT'), -- communicationRef
        (select id from "PartnerReferrerDO" where "shopRef" = shop_inTRONICS), -- sendingPartnerReferrerRef
        (select id from "PartnerReferrerDO" where "financeControllerRef" = (SELECT "id" FROM "FinanceControllerDO" WHERE "name" = 'FinanceController')), -- receivingPartnerReferrerRef
        5, -- maxNoOfRetries
        '1m', -- retryDelay
        null -- mergeTypeDefRef
    );

-- creditor management
-- everytime dispatches and returns are confirmed by the supplier(s), an XML will be exported to external finance controller
-- for dispatches, the finance controller will be informed how much money the shop-customer owes
-- for returns, the finance controller will be informed how much money should be paid to the shop-customer
-- shop specific
INSERT INTO "CommunicationPartnerDO"
("id", "decisionBeanDefRef", "splitTransmission", "communicationRef", "sendingPartnerReferrerRef", "receivingPartnerReferrerRef", "maxNoOfRetries", "retryDelay", "mergeTypeDefRef")
values(
        nextval('"CommunicationPartnerDO_id_seq"'), -- id
        null, -- decisionBeanDefRef
        FALSE, -- splitTransmission
        (select id from "CommunicationDO" where "key" = 'XML###MESSAGE_FILE_SENDER_BEAN###SEND_OPEN_AMOUNT'), -- communicationRef
        (select id from "PartnerReferrerDO" where "shopRef" = shop_inTRONICS_Business), -- sendingPartnerReferrerRef
        (select id from "PartnerReferrerDO" where "financeControllerRef" = (SELECT "id" FROM "FinanceControllerDO" WHERE "name" = 'FinanceController')), -- receivingPartnerReferrerRef
        5, -- maxNoOfRetries
        '1m', -- retryDelay
        null -- mergeTypeDefRef
    );	



-- debtor management
-- shop specific	
INSERT INTO "CommunicationPartnerDO"
("id", "decisionBeanDefRef", "splitTransmission", "communicationRef", "sendingPartnerReferrerRef", "receivingPartnerReferrerRef", "maxNoOfRetries", "retryDelay", "mergeTypeDefRef")
values(
        nextval('"CommunicationPartnerDO_id_seq"'), -- id
        null, -- decisionBeanDefRef
        FALSE, -- splitTransmission
        (select id from "CommunicationDO" where "key" = 'XML###MESSAGE_FILE_SENDER_BEAN###SEND_DEBITOR'), -- communicationRef
        (select id from "PartnerReferrerDO" where "shopRef" = shop_inTRONICS), -- sendingPartnerReferrerRef
        (select id from "PartnerReferrerDO" where "financeControllerRef" = (SELECT "id" FROM "FinanceControllerDO" WHERE "name" = 'FinanceController')), -- receivingPartnerReferrerRef
        5, -- maxNoOfRetries
        '1m', -- retryDelay
        null -- mergeTypeDefRef
    );

-- debtor management
-- shop specific
INSERT INTO "CommunicationPartnerDO"
("id", "decisionBeanDefRef", "splitTransmission", "communicationRef", "sendingPartnerReferrerRef", "receivingPartnerReferrerRef", "maxNoOfRetries", "retryDelay", "mergeTypeDefRef")
values(
        nextval('"CommunicationPartnerDO_id_seq"'), -- id
        null, -- decisionBeanDefRef
        FALSE, -- splitTransmission
        (select id from "CommunicationDO" where "key" = 'XML###MESSAGE_FILE_SENDER_BEAN###SEND_DEBITOR'), -- communicationRef
        (select id from "PartnerReferrerDO" where "shopRef" = shop_inTRONICS_Business), -- sendingPartnerReferrerRef
        (select id from "PartnerReferrerDO" where "financeControllerRef" = (SELECT "id" FROM "FinanceControllerDO" WHERE "name" = 'FinanceController')), -- receivingPartnerReferrerRef
        5, -- maxNoOfRetries
        '1m', -- retryDelay
        null -- mergeTypeDefRef
    );	


	
CREATE temp table SHOP_SUP
 AS   SELECT nextval('"OrderExportConfigDO_id_seq"') as seq_nr, shop_inTRONICS as shop_,  supplier_inTRONICS_Texas_Retailer as sup_ UNION ALL
					SELECT nextval('"OrderExportConfigDO_id_seq"') as seq_nr, shop_inTRONICS as shop_,  supplier_inTRONICS_Florida_Retailer as sup_ UNION ALL
					SELECT nextval('"OrderExportConfigDO_id_seq"') as seq_nr, shop_inTRONICS as shop_,  supplier_inTRONICS_California_Retailer as sup_ UNION ALL 
					SELECT nextval('"OrderExportConfigDO_id_seq"') as seq_nr, shop_inTRONICS_Business as shop_,  supplier_inTRONICS_Texas_Warehouse as sup_ UNION ALL 
					SELECT nextval('"OrderExportConfigDO_id_seq"') as seq_nr, shop_inTRONICS_Business as shop_,  supplier_inTRONICS_Florida_Warehouse as sup_ UNION ALL
					SELECT nextval('"OrderExportConfigDO_id_seq"') as seq_nr, shop_inTRONICS_Business as shop_,  supplier_inTRONICS_California_Warehouse as sup_ 
					;
 
INSERT INTO oms."OrderExportConfigDO"(
            "id",
            "active",
            "shopRef",
            "partnerReferrerRef",
            "exportStartTime",
            "lastRun",
            "startTimeMDB",
            "startTimeControl",
            "cronExportDate",
            "fileName",
            "exportBeanDefRef",
            "jobId",
            "ciffers",
            "encoding")
    SELECT seq_nr, -- id
            TRUE, -- active
            shop_, -- shopRef
            (select id from "PartnerReferrerDO" where "supplierRef" = sup_), -- supplierRef
            current_timestamp,
            NULL,
            NULL,
            NULL,
            '0 15 17 1/1 * ? *',
            'ReturnAnnouncementExport',
            10, -- select id from oms."OrderExportConfigBeanDefDO" where description = 'returnAnnouncementExportBean'
            NULL,
            NULL,
            NULL
from SHOP_SUP;
			


DROP TABLE SHOP_SUP;	
	
END;
$$;